Diarization lib
+++++++++++++++

INTRODUCTION
============

This GPL v3 package contains tool to build a speaker diarization system.


PREREQUISITES
=============

*Sidekit for Diarization* requires the following software installed for your platform:

1. [Python](http://www.python.org)
2. [NumPy](http://www.numpy.org/)
3. [Scipy](http://http://www.scipy.org/)
4. [Pandas](http://http://www.pandas.org/)
5. [GLPK](https://www.gnu.org/software/glpk/)
6. [Sphinx 1.1.0 or newer](http://http://sphinx-doc.org/) to build the documentation

INSTALLATION
============

We recommend the use of a virtual environment (e.g. [Miniconda](https://conda.io/miniconda.html) or [Virtualenv](https://virtualenv.readthedocs.io/en/latest/)).

TUTORIALS
=========

Once your installation is complete, you can take a look at the [tutorials](https://git-lium.univ-lemans.fr/Meignier/s4d/tree/master/tutorials).